package uoc.tfc.wimm;

import java.util.Calendar;

import uoc.tfc.wimm.R.layout;

import android.app.Activity;
import android.app.AlertDialog;
import android.view.View.OnClickListener;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.CheckBox;
import android.widget.Spinner;
import android.widget.TextView;


public class Consulta extends Activity implements OnClickListener{
	
	private TextView campoTitulo = null;
	private TextView campoIngreso = null;
	private TextView campoGasto = null;
	private TextView campoTotal = null;
	private Spinner spinnerCategoria = null;
	private int mes = 0;
	private int ano = 0;
	private double gastoTotal = 0;
	private double ingresoTotal = 0;
	private double resultadoTotal = 0;
	private View layout = null;
	private View checkBox = null;
	private boolean checkMarcada = false;
	Historial h = new Historial();
	Ahorro ahorro = new Ahorro();
	private double cantidadSuperada = 0;
	
	public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.consulta);
        
        campoTitulo = (TextView) findViewById(R.id.tituloConsulta);
        campoIngreso = (TextView)findViewById(R.id.valoIngreso);
        campoGasto = (TextView)findViewById(R.id.valorGasto);
        campoTotal = (TextView)findViewById(R.id.valorTotal);
        
        
        spinnerCategoria = (Spinner) findViewById(R.id.spinnerCategoriaConsulta);
        ArrayAdapter adapter = ArrayAdapter.createFromResource(this, R.array.categoriaTodas, android.R.layout.simple_spinner_item);
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        spinnerCategoria.setAdapter(adapter);
       
        
        View btn_consulta = findViewById(R.id.consulta);
        btn_consulta.setOnClickListener(this);
        
        View btn_atras = findViewById(R.id.atras);
        btn_atras.setOnClickListener(this);
        
        checkBox = findViewById(R.id.checkConsulta);
        checkBox.setOnClickListener(this);
        
        layout = findViewById(R.id.layoutCategoria);
        
        View btn_listadoIngreso = findViewById(R.id.listadoIngreso);
        btn_listadoIngreso.setOnClickListener(this);
        
        View btn_listadoGasto = findViewById(R.id.listadoGasto);
        btn_listadoGasto.setOnClickListener(this);
        
        if(h.getEsHistorico()){
        	mes = h.getMesHistorico();
        	ano = h.getAnoHistorico();
        }else{
        	Calendar c = Calendar.getInstance();
        	mes = c.get(Calendar.MONTH) + 1;
        	ano = c.get(Calendar.YEAR);
        	
        }
        inicializarMes();
        inicializarValores();
        
        if(ahorro.getEsAhorroActivado()){
        	consultaAhorro();
        }
        
	}
	
	
	private void consultaAhorro() {
		double ingreso = Double.valueOf(campoIngreso.getText().toString()).doubleValue();
		double gasto = Double.valueOf(campoGasto.getText().toString()).doubleValue();
		double valorPermitido = ahorro.getGastoPermitido(ingreso, gasto);
		
		if(gasto > valorPermitido){
			cantidadSuperada = gasto - valorPermitido;
			Intent i_ahorro = new Intent(this,ListadoAhorro.class);
			i_ahorro.putExtra("gasto", gasto);
			i_ahorro.putExtra("valorPermitido", valorPermitido);
			startActivity(i_ahorro);
		}
	}


	public void onClick(View v) {
		switch(v.getId()){
		case R.id.checkConsulta:
			if(!checkMarcada){
				layout.setVisibility(0);
				checkMarcada = true;
			}else{
				layout.setVisibility(4);
				checkMarcada = false;
			}
			break;
		case R.id.consulta:
			valoresSegunConcepto();
			break;
		case R.id.atras:
			h.setEsHistoric(false);
			Intent i = new Intent(this,WimmActivity.class);
			startActivity(i);
			finish();
			break;
		case R.id.listadoIngreso:
			startActivity(new Intent(this,ListarIngreso.class));
			finish();
			break;
		case R.id.listadoGasto:
			startActivity(new Intent(this,ListarGasto.class));
			finish();
			break;
		default:
			break;
		
		
		}
		
	}
	
	private void valoresSegunConcepto() {
		
        String fecha = String.valueOf(mes);
        fecha = fecha+""+String.valueOf(ano);
        WimmBDManager wimmBD = new WimmBDManager(this, "BDwimm", null, 1);
        SQLiteDatabase db = wimmBD.getReadableDatabase();
        
        String[] camposIng = new String[]{"cantidad","concepto"};
        String[] argsIng = new String[]{fecha};
        Cursor cursorIngreso = db.query("Ingresos", camposIng, "fecha=?", argsIng, null, null, null);
        
        if(cursorIngreso.moveToFirst()){
        	do{
        		String cantidad = cursorIngreso.getString(0);
        		double cant = Double.valueOf(cantidad).doubleValue();
        		String concepto = cursorIngreso.getString(1);
        		if(concepto.equals(spinnerCategoria.getSelectedItem().toString()) && checkMarcada){
        			ingresoTotal += cant;
        		}
        		
        	}while(cursorIngreso.moveToNext());
        }
        
        String[] camposGas = new String[]{"cantidad","concepto"};
        String[] argsGas = new String[]{fecha};
        Cursor cursorGasto = db.query("Gastos", camposGas, "fecha=?", argsGas, null, null, null);
        
        if(cursorGasto.moveToFirst()){
        	do{
        		String cantidad = cursorGasto.getString(0);
        		double cant = Double.valueOf(cantidad).doubleValue();
        		String concepto = cursorGasto.getString(1);
        		if(concepto.equals(spinnerCategoria.getSelectedItem().toString()) && checkMarcada){
        			gastoTotal += cant;
        		}
        	}while(cursorGasto.moveToNext());
        }
        
        resultadoTotal = ingresoTotal - gastoTotal;
        
        String txtSetIngreso = String.valueOf(ingresoTotal);
        String txtSetGasto = String.valueOf(gastoTotal);
        String txtSetTotal = String.valueOf(resultadoTotal);
        
        db.close();
        
        campoIngreso.setText(txtSetIngreso);
        campoGasto.setText(txtSetGasto);
        campoTotal.setText(txtSetTotal);
        
        ingresoTotal = 0;
        gastoTotal = 0;
        resultadoTotal = 0;
	}


	private void inicializarValores() {
        String fecha = String.valueOf(mes);
        fecha = fecha+""+String.valueOf(ano);
        WimmBDManager wimmBD = new WimmBDManager(this, "BDwimm", null, 1);
        SQLiteDatabase db = wimmBD.getReadableDatabase();
        
        String[] camposIng = new String[]{"cantidad","concepto"};
        String[] argsIng = new String[]{fecha};
        Cursor cursorIngreso = db.query("Ingresos", camposIng, "fecha=?", argsIng, null, null, null);
        
        if(cursorIngreso.moveToFirst()){
        	do{
        		String cantidad = cursorIngreso.getString(0);
        		double cant = Double.valueOf(cantidad).doubleValue();
        		ingresoTotal += cant;
        	}while(cursorIngreso.moveToNext());
        }
        
        String[] camposGas = new String[]{"cantidad","concepto"};
        String[] argsGas = new String[]{fecha};
        Cursor cursorGasto = db.query("Gastos", camposGas, "fecha=?", argsGas, null, null, null);
        
        if(cursorGasto.moveToFirst()){
        	do{
        		String cantidad = cursorGasto.getString(0);
        		double cant = Double.valueOf(cantidad).doubleValue();
        		gastoTotal += cant;
        	}while(cursorGasto.moveToNext());
        }
        
        resultadoTotal = ingresoTotal - gastoTotal;
        
        String txtSetIngreso = String.valueOf(ingresoTotal);
        String txtSetGasto = String.valueOf(gastoTotal);
        String txtSetTotal = String.valueOf(resultadoTotal);
        
        db.close();
        campoIngreso.setText(txtSetIngreso);
        campoGasto.setText(txtSetGasto);
        campoTotal.setText(txtSetTotal);
        
        ingresoTotal = 0;
        gastoTotal = 0;
        resultadoTotal = 0;
        
	}


	private void inicializarMes() {
		
		switch(mes){
		case 1:
			campoTitulo.setText(getText(R.string.lbl_titulo) +" "+ getText(R.string.enero));
			break;
		case 2:
			campoTitulo.setText(getText(R.string.lbl_titulo)+" "+ getText(R.string.febrero));
			break;
		case 3:
			campoTitulo.setText(getText(R.string.lbl_titulo) +" "+ getText(R.string.marzo));
			break;
		case 4:
			campoTitulo.setText(getText(R.string.lbl_titulo)+" "+ getText(R.string.abril));
			break;
		case 5:
			campoTitulo.setText(getText(R.string.lbl_titulo) +" "+ getText(R.string.mayo));
			break;
		case 6:
			campoTitulo.setText(getText(R.string.lbl_titulo)+" "+ getText(R.string.junio));
			break;
		case 7:
			campoTitulo.setText(getText(R.string.lbl_titulo)+" "+ getText(R.string.julio));
			break;
		case 8:
			campoTitulo.setText(getText(R.string.lbl_titulo)+" "+ getText(R.string.agosto));
			break;
		case 9:
			campoTitulo.setText(getText(R.string.lbl_titulo)+" "+ getText(R.string.septiembre));
			break;
		case 10:
			campoTitulo.setText(getText(R.string.lbl_titulo)+" "+ getText(R.string.octubre));
			break;
		case 11:
			campoTitulo.setText(getText(R.string.lbl_titulo)+" "+ getText(R.string.noviembre));
			break;
		case 12:
			campoTitulo.setText(getText(R.string.lbl_titulo)+" "+ getText(R.string.diciembre));
			break;
		default:
			campoTitulo.setText(getText(R.string.lbl_titulo));
			break;
			
		}
		
	}


	public boolean onCreateOptionsMenu (Menu menu){
    	super.onCreateOptionsMenu(menu);
    	MenuInflater inflater = getMenuInflater();
    	inflater.inflate(R.menu.menuconsulta, menu);
    	return true;
    }
	
	
	public boolean onMenuItemSelected(int featureId, MenuItem item){
    	super.onMenuItemSelected(featureId, item);
    	switch(item.getItemId()){
    	case R.id.salirCons:
    		h.setEsHistoric(false);
    		finish();
    		break;
    	default:
    		break;
    	}
    	return true;
    }

	
	
}
